@@ -20,12 +20,13 @@ as part of L<Net::ACME2::Authorization> instantiation.
 
 use parent qw( Net::ACME2::AccessorBase );
 
+use Net::ACME2::Error ();
+
 use constant _ACCESSORS => (
     'url',
     'type',
     'status',
     'validated',
-    'error',
     'token',
 );
 
@@ -47,6 +48,15 @@ These provide text strings as defined in the ACME specification.
 
 =back
 
+An C<error()> accessor is also provided, which returns the error object
+as a L<Net::ACME2::Error> instance (or undef if there is no error).
+
 =cut
 
+sub error {
+    my ($self) = @_;
+
+    return $self->{'_error'} && Net::ACME2::Error->new( %{ $self->{'_error'} } );
+}
+
 1;
