@@ -3,7 +3,7 @@ package Net::ACME2::X::Empty;
 use strict;
 use warnings;
 
-use parent qw( Net::ACME2::X::Base );
+use parent qw( Net::ACME2::X::Generic );
 
 sub new {
     my ( $class, $args_hr ) = @_;
